@@ -10,13 +10,15 @@ import time
 #!                              !
 #!------------------------------!
 
+lvers = "1.0.9"
 
-def checkver:
+
+def checkver():
     packagenm = 'ngrok_info'  # replace with the package you want to check
     responseinfl = requests.get(f'https://pypi.org/pypi/{packagenm}/json')
     latest_version = responseinfl.json()['info']['version']
-    if latest_version != 1.0.6:
-        print("You are not using latest version, run 'python3 -m pip install ngrok_info'")
+    if latest_version != lvers:
+        print("You are not using latest version, run 'python3 -m pip install ngrok_info --upgrade'")
 
 checkver()
 
